# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            total = schemas.IntSchema
            
            
            class trust_level(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        high = schemas.IntSchema
                        medium = schemas.IntSchema
                        low = schemas.IntSchema
                        always_allow = schemas.IntSchema
                        always_deny = schemas.IntSchema
                        unknown = schemas.IntSchema
                        __annotations__ = {
                            "high": high,
                            "medium": medium,
                            "low": low,
                            "always_allow": always_allow,
                            "always_deny": always_deny,
                            "unknown": unknown,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["high"]) -> MetaOapg.properties.high: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["medium"]) -> MetaOapg.properties.medium: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["low"]) -> MetaOapg.properties.low: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["always_allow"]) -> MetaOapg.properties.always_allow: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["always_deny"]) -> MetaOapg.properties.always_deny: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["unknown"]) -> MetaOapg.properties.unknown: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["high", "medium", "low", "always_allow", "always_deny", "unknown", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["high"]) -> typing.Union[MetaOapg.properties.high, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["medium"]) -> typing.Union[MetaOapg.properties.medium, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["low"]) -> typing.Union[MetaOapg.properties.low, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["always_allow"]) -> typing.Union[MetaOapg.properties.always_allow, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["always_deny"]) -> typing.Union[MetaOapg.properties.always_deny, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["unknown"]) -> typing.Union[MetaOapg.properties.unknown, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["high", "medium", "low", "always_allow", "always_deny", "unknown", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    high: typing.Union[MetaOapg.properties.high, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    medium: typing.Union[MetaOapg.properties.medium, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    low: typing.Union[MetaOapg.properties.low, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    always_allow: typing.Union[MetaOapg.properties.always_allow, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    always_deny: typing.Union[MetaOapg.properties.always_deny, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    unknown: typing.Union[MetaOapg.properties.unknown, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'trust_level':
                    return super().__new__(
                        cls,
                        *args,
                        high=high,
                        medium=medium,
                        low=low,
                        always_allow=always_allow,
                        always_deny=always_deny,
                        unknown=unknown,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class os(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        macOS = schemas.IntSchema
                        linux = schemas.IntSchema
                        windows = schemas.IntSchema
                        iOS = schemas.IntSchema
                        unknown = schemas.IntSchema
                        __annotations__ = {
                            "macOS": macOS,
                            "linux": linux,
                            "windows": windows,
                            "iOS": iOS,
                            "unknown": unknown,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["macOS"]) -> MetaOapg.properties.macOS: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["linux"]) -> MetaOapg.properties.linux: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["windows"]) -> MetaOapg.properties.windows: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["iOS"]) -> MetaOapg.properties.iOS: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["unknown"]) -> MetaOapg.properties.unknown: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["macOS", "linux", "windows", "iOS", "unknown", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["macOS"]) -> typing.Union[MetaOapg.properties.macOS, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["linux"]) -> typing.Union[MetaOapg.properties.linux, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["windows"]) -> typing.Union[MetaOapg.properties.windows, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["iOS"]) -> typing.Union[MetaOapg.properties.iOS, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["unknown"]) -> typing.Union[MetaOapg.properties.unknown, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["macOS", "linux", "windows", "iOS", "unknown", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    macOS: typing.Union[MetaOapg.properties.macOS, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    linux: typing.Union[MetaOapg.properties.linux, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    windows: typing.Union[MetaOapg.properties.windows, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    iOS: typing.Union[MetaOapg.properties.iOS, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    unknown: typing.Union[MetaOapg.properties.unknown, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'os':
                    return super().__new__(
                        cls,
                        *args,
                        macOS=macOS,
                        linux=linux,
                        windows=windows,
                        iOS=iOS,
                        unknown=unknown,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "total": total,
                "trust_level": trust_level,
                "os": os,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["total"]) -> MetaOapg.properties.total: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["trust_level"]) -> MetaOapg.properties.trust_level: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["os"]) -> MetaOapg.properties.os: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["total", "trust_level", "os", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["total"]) -> typing.Union[MetaOapg.properties.total, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["trust_level"]) -> typing.Union[MetaOapg.properties.trust_level, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["os"]) -> typing.Union[MetaOapg.properties.os, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["total", "trust_level", "os", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        total: typing.Union[MetaOapg.properties.total, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        trust_level: typing.Union[MetaOapg.properties.trust_level, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        os: typing.Union[MetaOapg.properties.os, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            total=total,
            trust_level=trust_level,
            os=os,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v1_devices_stats_get_oapg(
        self: api_client.Api,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         Get the devices statistics for an org
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        used_path = path.value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V1DevicesStatsGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v1_devices_stats_get(
        self: BaseApi,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_devices_stats_get_oapg(
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_devices_stats_get_oapg(
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# do not import all endpoints into this module because that uses a lot of memory and stack frames
# if you need the ability to import all endpoints from this module, import them with
# from banyanclient.apis.path_to_api import path_to_api

import enum


class PathValues(str, enum.Enum):
    V1_ENABLE_REGISTERED_SERVICE = "/v1/enable_registered_service"
    V1_SERVICES_STATS = "/v1/services/stats"
    V1_SERVICE_CONNECTION_TEST = "/v1/service_connection_test"
    V1_INSERT_REGISTERED_SERVICE = "/v1/insert_registered_service"
    V2_ACCESS_TIER_ID_REGISTERED_SERVICES = "/v2/access_tier/{id}/registered_services"
    V1_REGISTERED_SERVICES = "/v1/registered_services"
    V1_DELETE_REGISTERED_SERVICE = "/v1/delete_registered_service"
    V1_DISABLE_REGISTERED_SERVICE = "/v1/disable_registered_service"
    V2_BUNDLE_BUNDLE_ID = "/v2/bundle/{bundle_id}"
    V2_BUNDLE = "/v2/bundle"
    V2_BUNDLE_BUNDLE_ID_SERVICE = "/v2/bundle/{bundle_id}/service"
    V2_BUNDLE_BUNDLE_ID_SERVICE_SERVICE_ID = "/v2/bundle/{bundle_id}/service/{service_id}"
    V2_SERVICE_TUNNEL = "/v2/service_tunnel"
    SERVICE_TUNNEL_ID_SECURITY_POLICY_POLICY_ID = "/service_tunnel/{id}/security_policy/{policy_id}"
    SERVICE_TUNNEL_ID_SECURITY_POLICY = "/service_tunnel/{id}/security_policy"
    V2_SERVICE_TUNNEL_ID = "/v2/service_tunnel/{id}"
    V1_INSERT_SAASAPP = "/v1/insert_saasapp"
    V1_POLICY_POLICY_ID_ATTACHMENT = "/v1/policy/{policyID}/attachment"
    V1_SECURITY_POLICIES = "/v1/security_policies"
    V1_SECURITY_ATTACH_POLICIES = "/v1/security_attach_policies"
    V1_POLICIES_STATS = "/v1/policies/stats"
    V1_POLICY_ATTACHMENT_ATTACHED_TO_TYPE_ATTACHED_TO_ID = "/v1/policy/attachment/{attachedToType}/{attachedToID}"
    V1_POLICY_ATTACHMENT_ATTACHED_TO_TYPE = "/v1/policy/attachment/{attachedToType}"
    V1_DELETE_SECURITY_POLICY = "/v1/delete_security_policy"
    V1_INSERT_SECURITY_ATTACH_POLICY = "/v1/insert_security_attach_policy"
    V1_POLICY_ATTACHMENT = "/v1/policy/attachment"
    V1_DELETE_SECURITY_ATTACH_POLICY = "/v1/delete_security_attach_policy"
    V1_INSERT_SECURITY_POLICY = "/v1/insert_security_policy"
    V1_SECURITYROLES_STATS = "/v1/securityroles/stats"
    V1_DISABLE_SECURITY_ROLE = "/v1/disable_security_role"
    V1_INSERT_SECURITY_ROLE = "/v1/insert_security_role"
    V1_ENABLE_SECURITY_ROLE = "/v1/enable_security_role"
    V1_SECURITY_ROLES_ENDUSER_DEVICES = "/v1/security_roles/enduser_devices"
    V1_DELETE_SECURITY_ROLE = "/v1/delete_security_role"
    V1_SECURITY_ROLES = "/v1/security_roles"
    V1_UNREGISTERED_DEVICE_ENDUSERS_CSV = "/v1/unregistered_device/endusers/csv"
    V1_ENDUSERS_STATS = "/v1/endusers/stats"
    V2_ENDUSERS = "/v2/endusers"
    V1_MDM_INSERT_DEVICES = "/v1/mdm/insert_devices"
    V2_ENDUSER_GROUPS = "/v2/enduser_groups"
    V1_ENDUSERS = "/v1/endusers"
    V1_ENDUSER_DEVICES_DATA = "/v1/enduser_devices/data"
    V2_ENDUSER = "/v2/enduser"
    V1_ENDUSERS_CSV = "/v1/endusers/csv"
    V2_ENDUSER_ID = "/v2/enduser/{id}"
    V1_DELETE_DEVICE = "/v1/delete_device"
    V1_SEND_DEVICE_NOTIFICATION = "/v1/send_device_notification"
    V2_DEVICES_CSV = "/v2/devices/csv"
    V2_DEVICES = "/v2/devices"
    V1_ENDUSER_DEVICES = "/v1/enduser_devices"
    V1_MDM_DEVICE_INFO = "/v1/mdm/device_info"
    V1_DEVICE_ID_TOKEN = "/v1/device/id_token"
    V1_MDM_UPDATE_DEVICE = "/v1/mdm/update_device"
    V1_DEVICES_STATS = "/v1/devices/stats"
    V1_DEVICES = "/v1/devices"
    V1_EVENTS = "/v1/events"
    V2_EVENT_DAILY_COUNTS = "/v2/event/daily_counts"
    V1_EVENT_TYPES = "/v1/event_types"
    V1_EVENTS_FEED = "/v1/events/feed"
    V1_EVENTS_COUNT = "/v1/events/count"
    V1_AUDIT_LOGS = "/v1/audit_logs"
    V2_ACCESS_TIER_ID = "/v2/access_tier/{id}"
    V1_ACCESS_TIERS_STATS = "/v1/access_tiers/stats"
    V2_ACCESS_TIER = "/v2/access_tier"
    V1_ONE_CLICK_SUPPORT_BUNDLE = "/v1/one_click_support_bundle"
    V1_SERVICE_HOSTNAME_MAPPING = "/v1/service_hostname_mapping"
    V2_ACCESS_TIER_ACCESS_TIER_ID_TUNNEL_CONFIG_TUNNEL_CONFIG_ID = "/v2/access_tier/{access_tier_id}/tunnel_config/{tunnel_config_id}"
    V2_SATELLITE = "/v2/satellite"
    V2_SATELLITE_ID = "/v2/satellite/{id}"
    V2_CONNECTOR_STATS = "/v2/connector/stats"
    V2_CLOUD_RESOURCE_ID = "/v2/cloud_resource/{id}"
    V2_CLOUD_RESOURCE_SERVICE_ID = "/v2/cloud_resource_service/{id}"
    V2_CLOUD_RESOURCE_SERVICE = "/v2/cloud_resource_service"
    V2_API_KEY_ID = "/v2/api_key/{id}"
    V2_API_KEY_SCOPE = "/v2/api_key/scope"
    V2_API_KEY = "/v2/api_key"



# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.v2_api_key.get import V2ApiKeyGet
from banyanclient.paths.v2_api_key_id.delete import V2ApiKeyIdDelete
from banyanclient.paths.v2_api_key_id.get import V2ApiKeyIdGet
from banyanclient.paths.v2_api_key_id.put import V2ApiKeyIdPut
from banyanclient.paths.v2_api_key.post import V2ApiKeyPost
from banyanclient.paths.v2_api_key_scope.get import V2ApiKeyScopeGet


class ApiKeyApi(
    V2ApiKeyGet,
    V2ApiKeyIdDelete,
    V2ApiKeyIdGet,
    V2ApiKeyIdPut,
    V2ApiKeyPost,
    V2ApiKeyScopeGet,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass



# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
LimitSchema = schemas.IntSchema
SkipSchema = schemas.IntSchema
SecurityRoleIdSchema = schemas.StrSchema
EmailSchema = schemas.StrSchema
SerialnumberSchema = schemas.StrSchema
ExactEmailSchema = schemas.StrSchema
ExactSerialNumberSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'limit': typing.Union[LimitSchema, decimal.Decimal, int, ],
        'skip': typing.Union[SkipSchema, decimal.Decimal, int, ],
        'security_role_id': typing.Union[SecurityRoleIdSchema, str, ],
        'email': typing.Union[EmailSchema, str, ],
        'serialnumber': typing.Union[SerialnumberSchema, str, ],
        'exact_email': typing.Union[ExactEmailSchema, str, ],
        'exact_serial_number': typing.Union[ExactSerialNumberSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_limit = api_client.QueryParameter(
    name="limit",
    style=api_client.ParameterStyle.FORM,
    schema=LimitSchema,
    explode=True,
)
request_query_skip = api_client.QueryParameter(
    name="skip",
    style=api_client.ParameterStyle.FORM,
    schema=SkipSchema,
    explode=True,
)
request_query_security_role_id = api_client.QueryParameter(
    name="security_role_id",
    style=api_client.ParameterStyle.FORM,
    schema=SecurityRoleIdSchema,
    explode=True,
)
request_query_email = api_client.QueryParameter(
    name="email",
    style=api_client.ParameterStyle.FORM,
    schema=EmailSchema,
    explode=True,
)
request_query_serialnumber = api_client.QueryParameter(
    name="serialnumber",
    style=api_client.ParameterStyle.FORM,
    schema=SerialnumberSchema,
    explode=True,
)
request_query_exact_email = api_client.QueryParameter(
    name="exact_email",
    style=api_client.ParameterStyle.FORM,
    schema=ExactEmailSchema,
    explode=True,
)
request_query_exact_serial_number = api_client.QueryParameter(
    name="exact_serial_number",
    style=api_client.ParameterStyle.FORM,
    schema=ExactSerialNumberSchema,
    explode=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            
            
            class enduserdevices(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    
                    
                    class items(
                        schemas.DictSchema
                    ):
                    
                    
                        class MetaOapg:
                            
                            class properties:
                                
                                
                                class enduser(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            ID = schemas.StrSchema
                                            OrgID = schemas.StrSchema
                                            Email = schemas.StrSchema
                                            Name = schemas.StrSchema
                                            CreatedAt = schemas.IntSchema
                                            __annotations__ = {
                                                "ID": ID,
                                                "OrgID": OrgID,
                                                "Email": Email,
                                                "Name": Name,
                                                "CreatedAt": CreatedAt,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["ID"]) -> MetaOapg.properties.ID: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["OrgID"]) -> MetaOapg.properties.OrgID: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Email"]) -> MetaOapg.properties.Email: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Name"]) -> MetaOapg.properties.Name: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["CreatedAt"]) -> MetaOapg.properties.CreatedAt: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["ID", "OrgID", "Email", "Name", "CreatedAt", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["ID"]) -> typing.Union[MetaOapg.properties.ID, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["OrgID"]) -> typing.Union[MetaOapg.properties.OrgID, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Email"]) -> typing.Union[MetaOapg.properties.Email, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Name"]) -> typing.Union[MetaOapg.properties.Name, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["CreatedAt"]) -> typing.Union[MetaOapg.properties.CreatedAt, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ID", "OrgID", "Email", "Name", "CreatedAt", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        ID: typing.Union[MetaOapg.properties.ID, str, schemas.Unset] = schemas.unset,
                                        OrgID: typing.Union[MetaOapg.properties.OrgID, str, schemas.Unset] = schemas.unset,
                                        Email: typing.Union[MetaOapg.properties.Email, str, schemas.Unset] = schemas.unset,
                                        Name: typing.Union[MetaOapg.properties.Name, str, schemas.Unset] = schemas.unset,
                                        CreatedAt: typing.Union[MetaOapg.properties.CreatedAt, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'enduser':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            ID=ID,
                                            OrgID=OrgID,
                                            Email=Email,
                                            Name=Name,
                                            CreatedAt=CreatedAt,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                
                                
                                class device(
                                    schemas.DictSchema
                                ):
                                
                                
                                    class MetaOapg:
                                        
                                        class properties:
                                            ID = schemas.StrSchema
                                            OrgID = schemas.StrSchema
                                            SerialNumber = schemas.StrSchema
                                            Name = schemas.StrSchema
                                            Model = schemas.StrSchema
                                            Ownership = schemas.StrSchema
                                            Platform = schemas.StrSchema
                                            Architecture = schemas.StrSchema
                                            Source = schemas.StrSchema
                                            Banned = schemas.IntSchema
                                            OS = schemas.StrSchema
                                            MDMPresent = schemas.IntSchema
                                            MDMVendorName = schemas.StrSchema
                                            MDMVendorUDID = schemas.StrSchema
                                            LastMDMDataSyncedAt = schemas.IntSchema
                                            MDMCompliant = schemas.StrSchema
                                            AppVersion = schemas.StrSchema
                                            CreatedAt = schemas.IntSchema
                                            __annotations__ = {
                                                "ID": ID,
                                                "OrgID": OrgID,
                                                "SerialNumber": SerialNumber,
                                                "Name": Name,
                                                "Model": Model,
                                                "Ownership": Ownership,
                                                "Platform": Platform,
                                                "Architecture": Architecture,
                                                "Source": Source,
                                                "Banned": Banned,
                                                "OS": OS,
                                                "MDMPresent": MDMPresent,
                                                "MDMVendorName": MDMVendorName,
                                                "MDMVendorUDID": MDMVendorUDID,
                                                "LastMDMDataSyncedAt": LastMDMDataSyncedAt,
                                                "MDMCompliant": MDMCompliant,
                                                "AppVersion": AppVersion,
                                                "CreatedAt": CreatedAt,
                                            }
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["ID"]) -> MetaOapg.properties.ID: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["OrgID"]) -> MetaOapg.properties.OrgID: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["SerialNumber"]) -> MetaOapg.properties.SerialNumber: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Name"]) -> MetaOapg.properties.Name: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Model"]) -> MetaOapg.properties.Model: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Ownership"]) -> MetaOapg.properties.Ownership: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Platform"]) -> MetaOapg.properties.Platform: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Architecture"]) -> MetaOapg.properties.Architecture: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Source"]) -> MetaOapg.properties.Source: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["Banned"]) -> MetaOapg.properties.Banned: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["OS"]) -> MetaOapg.properties.OS: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["MDMPresent"]) -> MetaOapg.properties.MDMPresent: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["MDMVendorName"]) -> MetaOapg.properties.MDMVendorName: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["MDMVendorUDID"]) -> MetaOapg.properties.MDMVendorUDID: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["LastMDMDataSyncedAt"]) -> MetaOapg.properties.LastMDMDataSyncedAt: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["MDMCompliant"]) -> MetaOapg.properties.MDMCompliant: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["AppVersion"]) -> MetaOapg.properties.AppVersion: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: typing_extensions.Literal["CreatedAt"]) -> MetaOapg.properties.CreatedAt: ...
                                    
                                    @typing.overload
                                    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                                    
                                    def __getitem__(self, name: typing.Union[typing_extensions.Literal["ID", "OrgID", "SerialNumber", "Name", "Model", "Ownership", "Platform", "Architecture", "Source", "Banned", "OS", "MDMPresent", "MDMVendorName", "MDMVendorUDID", "LastMDMDataSyncedAt", "MDMCompliant", "AppVersion", "CreatedAt", ], str]):
                                        # dict_instance[name] accessor
                                        return super().__getitem__(name)
                                    
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["ID"]) -> typing.Union[MetaOapg.properties.ID, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["OrgID"]) -> typing.Union[MetaOapg.properties.OrgID, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["SerialNumber"]) -> typing.Union[MetaOapg.properties.SerialNumber, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Name"]) -> typing.Union[MetaOapg.properties.Name, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Model"]) -> typing.Union[MetaOapg.properties.Model, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Ownership"]) -> typing.Union[MetaOapg.properties.Ownership, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Platform"]) -> typing.Union[MetaOapg.properties.Platform, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Architecture"]) -> typing.Union[MetaOapg.properties.Architecture, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Source"]) -> typing.Union[MetaOapg.properties.Source, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["Banned"]) -> typing.Union[MetaOapg.properties.Banned, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["OS"]) -> typing.Union[MetaOapg.properties.OS, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["MDMPresent"]) -> typing.Union[MetaOapg.properties.MDMPresent, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["MDMVendorName"]) -> typing.Union[MetaOapg.properties.MDMVendorName, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["MDMVendorUDID"]) -> typing.Union[MetaOapg.properties.MDMVendorUDID, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["LastMDMDataSyncedAt"]) -> typing.Union[MetaOapg.properties.LastMDMDataSyncedAt, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["MDMCompliant"]) -> typing.Union[MetaOapg.properties.MDMCompliant, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["AppVersion"]) -> typing.Union[MetaOapg.properties.AppVersion, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: typing_extensions.Literal["CreatedAt"]) -> typing.Union[MetaOapg.properties.CreatedAt, schemas.Unset]: ...
                                    
                                    @typing.overload
                                    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                                    
                                    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["ID", "OrgID", "SerialNumber", "Name", "Model", "Ownership", "Platform", "Architecture", "Source", "Banned", "OS", "MDMPresent", "MDMVendorName", "MDMVendorUDID", "LastMDMDataSyncedAt", "MDMCompliant", "AppVersion", "CreatedAt", ], str]):
                                        return super().get_item_oapg(name)
                                    
                                
                                    def __new__(
                                        cls,
                                        *args: typing.Union[dict, frozendict.frozendict, ],
                                        ID: typing.Union[MetaOapg.properties.ID, str, schemas.Unset] = schemas.unset,
                                        OrgID: typing.Union[MetaOapg.properties.OrgID, str, schemas.Unset] = schemas.unset,
                                        SerialNumber: typing.Union[MetaOapg.properties.SerialNumber, str, schemas.Unset] = schemas.unset,
                                        Name: typing.Union[MetaOapg.properties.Name, str, schemas.Unset] = schemas.unset,
                                        Model: typing.Union[MetaOapg.properties.Model, str, schemas.Unset] = schemas.unset,
                                        Ownership: typing.Union[MetaOapg.properties.Ownership, str, schemas.Unset] = schemas.unset,
                                        Platform: typing.Union[MetaOapg.properties.Platform, str, schemas.Unset] = schemas.unset,
                                        Architecture: typing.Union[MetaOapg.properties.Architecture, str, schemas.Unset] = schemas.unset,
                                        Source: typing.Union[MetaOapg.properties.Source, str, schemas.Unset] = schemas.unset,
                                        Banned: typing.Union[MetaOapg.properties.Banned, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        OS: typing.Union[MetaOapg.properties.OS, str, schemas.Unset] = schemas.unset,
                                        MDMPresent: typing.Union[MetaOapg.properties.MDMPresent, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        MDMVendorName: typing.Union[MetaOapg.properties.MDMVendorName, str, schemas.Unset] = schemas.unset,
                                        MDMVendorUDID: typing.Union[MetaOapg.properties.MDMVendorUDID, str, schemas.Unset] = schemas.unset,
                                        LastMDMDataSyncedAt: typing.Union[MetaOapg.properties.LastMDMDataSyncedAt, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        MDMCompliant: typing.Union[MetaOapg.properties.MDMCompliant, str, schemas.Unset] = schemas.unset,
                                        AppVersion: typing.Union[MetaOapg.properties.AppVersion, str, schemas.Unset] = schemas.unset,
                                        CreatedAt: typing.Union[MetaOapg.properties.CreatedAt, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                        _configuration: typing.Optional[schemas.Configuration] = None,
                                        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                                    ) -> 'device':
                                        return super().__new__(
                                            cls,
                                            *args,
                                            ID=ID,
                                            OrgID=OrgID,
                                            SerialNumber=SerialNumber,
                                            Name=Name,
                                            Model=Model,
                                            Ownership=Ownership,
                                            Platform=Platform,
                                            Architecture=Architecture,
                                            Source=Source,
                                            Banned=Banned,
                                            OS=OS,
                                            MDMPresent=MDMPresent,
                                            MDMVendorName=MDMVendorName,
                                            MDMVendorUDID=MDMVendorUDID,
                                            LastMDMDataSyncedAt=LastMDMDataSyncedAt,
                                            MDMCompliant=MDMCompliant,
                                            AppVersion=AppVersion,
                                            CreatedAt=CreatedAt,
                                            _configuration=_configuration,
                                            **kwargs,
                                        )
                                __annotations__ = {
                                    "enduser": enduser,
                                    "device": device,
                                }
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["enduser"]) -> MetaOapg.properties.enduser: ...
                        
                        @typing.overload
                        def __getitem__(self, name: typing_extensions.Literal["device"]) -> MetaOapg.properties.device: ...
                        
                        @typing.overload
                        def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                        
                        def __getitem__(self, name: typing.Union[typing_extensions.Literal["enduser", "device", ], str]):
                            # dict_instance[name] accessor
                            return super().__getitem__(name)
                        
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["enduser"]) -> typing.Union[MetaOapg.properties.enduser, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: typing_extensions.Literal["device"]) -> typing.Union[MetaOapg.properties.device, schemas.Unset]: ...
                        
                        @typing.overload
                        def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                        
                        def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["enduser", "device", ], str]):
                            return super().get_item_oapg(name)
                        
                    
                        def __new__(
                            cls,
                            *args: typing.Union[dict, frozendict.frozendict, ],
                            enduser: typing.Union[MetaOapg.properties.enduser, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            device: typing.Union[MetaOapg.properties.device, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                            _configuration: typing.Optional[schemas.Configuration] = None,
                            **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                        ) -> 'items':
                            return super().__new__(
                                cls,
                                *args,
                                enduser=enduser,
                                device=device,
                                _configuration=_configuration,
                                **kwargs,
                            )
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]], typing.List[typing.Union[MetaOapg.items, dict, frozendict.frozendict, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'enduserdevices':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            count = schemas.IntSchema
            __annotations__ = {
                "enduserdevices": enduserdevices,
                "count": count,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["enduserdevices"]) -> MetaOapg.properties.enduserdevices: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["count"]) -> MetaOapg.properties.count: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["enduserdevices", "count", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["enduserdevices"]) -> typing.Union[MetaOapg.properties.enduserdevices, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["count"]) -> typing.Union[MetaOapg.properties.count, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["enduserdevices", "count", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        enduserdevices: typing.Union[MetaOapg.properties.enduserdevices, list, tuple, schemas.Unset] = schemas.unset,
        count: typing.Union[MetaOapg.properties.count, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            enduserdevices=enduserdevices,
            count=count,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
)


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v1_security_roles_enduser_devices_get_oapg(
        self: api_client.Api,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         List Enduser and Device pairs for given role id
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_limit,
            request_query_skip,
            request_query_security_role_id,
            request_query_email,
            request_query_serialnumber,
            request_query_exact_email,
            request_query_exact_serial_number,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        response = self.api_client.call_api(
            resource_path=used_path,
            method='get'.upper(),
            headers=_headers,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V1SecurityRolesEnduserDevicesGet(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v1_security_roles_enduser_devices_get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_security_roles_enduser_devices_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForget(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def get(
        self: BaseApi,
        query_params: RequestQueryParams = frozendict.frozendict(),
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v1_security_roles_enduser_devices_get_oapg(
            query_params=query_params,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""


    Generated by: https://openapi-generator.tech
"""

from dataclasses import dataclass
import typing_extensions
import urllib3
from urllib3._collections import HTTPHeaderDict

from banyanclient import api_client, exceptions
from datetime import date, datetime  # noqa: F401
import decimal  # noqa: F401
import functools  # noqa: F401
import io  # noqa: F401
import re  # noqa: F401
import typing  # noqa: F401
import typing_extensions  # noqa: F401
import uuid  # noqa: F401

import frozendict  # noqa: F401

from banyanclient import schemas  # noqa: F401

from . import path

# query params
NameSchema = schemas.StrSchema
AddressSchema = schemas.StrSchema
DomainsSchema = schemas.DictSchema
TunnelSatelliteSchema = schemas.DictSchema
TunnelEnduserSchema = schemas.DictSchema
ClusterNameSchema = schemas.StrSchema
RequestRequiredQueryParams = typing_extensions.TypedDict(
    'RequestRequiredQueryParams',
    {
    }
)
RequestOptionalQueryParams = typing_extensions.TypedDict(
    'RequestOptionalQueryParams',
    {
        'name': typing.Union[NameSchema, str, ],
        'address': typing.Union[AddressSchema, str, ],
        'domains': typing.Union[DomainsSchema, dict, frozendict.frozendict, ],
        'tunnel satellite': typing.Union[TunnelSatelliteSchema, dict, frozendict.frozendict, ],
        'tunnel enduser': typing.Union[TunnelEnduserSchema, dict, frozendict.frozendict, ],
        'cluster_name': typing.Union[ClusterNameSchema, str, ],
    },
    total=False
)


class RequestQueryParams(RequestRequiredQueryParams, RequestOptionalQueryParams):
    pass


request_query_name = api_client.QueryParameter(
    name="name",
    style=api_client.ParameterStyle.FORM,
    schema=NameSchema,
    explode=True,
)
request_query_address = api_client.QueryParameter(
    name="address",
    style=api_client.ParameterStyle.FORM,
    schema=AddressSchema,
    explode=True,
)
request_query_domains = api_client.QueryParameter(
    name="domains",
    style=api_client.ParameterStyle.FORM,
    schema=DomainsSchema,
    explode=True,
)
request_query_tunnel_satellite = api_client.QueryParameter(
    name="tunnel satellite",
    style=api_client.ParameterStyle.FORM,
    schema=TunnelSatelliteSchema,
    explode=True,
)
request_query_tunnel_enduser = api_client.QueryParameter(
    name="tunnel enduser",
    style=api_client.ParameterStyle.FORM,
    schema=TunnelEnduserSchema,
    explode=True,
)
request_query_cluster_name = api_client.QueryParameter(
    name="cluster_name",
    style=api_client.ParameterStyle.FORM,
    schema=ClusterNameSchema,
    explode=True,
)
# body param


class SchemaForRequestBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            name = schemas.StrSchema
            address = schemas.StrSchema
            
            
            class domains(
                schemas.ListSchema
            ):
            
            
                class MetaOapg:
                    items = schemas.StrSchema
            
                def __new__(
                    cls,
                    arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                    _configuration: typing.Optional[schemas.Configuration] = None,
                ) -> 'domains':
                    return super().__new__(
                        cls,
                        arg,
                        _configuration=_configuration,
                    )
            
                def __getitem__(self, i: int) -> MetaOapg.items:
                    return super().__getitem__(i)
            cluster_name = schemas.StrSchema
            disable_snat = schemas.IntSchema
            src_nat_cidr_range = schemas.StrSchema
            
            
            class tunnel_satellite(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        dns_search_domains = schemas.StrSchema
                        udp_port_number = schemas.IntSchema
                        dns_enabled = schemas.IntSchema
                        keepalive = schemas.IntSchema
                        
                        
                        class cidrs(
                            schemas.ListSchema
                        ):
                        
                        
                            class MetaOapg:
                                items = schemas.StrSchema
                        
                            def __new__(
                                cls,
                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'cidrs':
                                return super().__new__(
                                    cls,
                                    arg,
                                    _configuration=_configuration,
                                )
                        
                            def __getitem__(self, i: int) -> MetaOapg.items:
                                return super().__getitem__(i)
                        
                        
                        class domains(
                            schemas.ListSchema
                        ):
                        
                        
                            class MetaOapg:
                                items = schemas.StrSchema
                        
                            def __new__(
                                cls,
                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'domains':
                                return super().__new__(
                                    cls,
                                    arg,
                                    _configuration=_configuration,
                                )
                        
                            def __getitem__(self, i: int) -> MetaOapg.items:
                                return super().__getitem__(i)
                        __annotations__ = {
                            "dns_search_domains": dns_search_domains,
                            "udp_port_number": udp_port_number,
                            "dns_enabled": dns_enabled,
                            "keepalive": keepalive,
                            "cidrs": cidrs,
                            "domains": domains,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["dns_search_domains"]) -> MetaOapg.properties.dns_search_domains: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["udp_port_number"]) -> MetaOapg.properties.udp_port_number: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["dns_enabled"]) -> MetaOapg.properties.dns_enabled: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["keepalive"]) -> MetaOapg.properties.keepalive: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["cidrs"]) -> MetaOapg.properties.cidrs: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["dns_search_domains", "udp_port_number", "dns_enabled", "keepalive", "cidrs", "domains", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["dns_search_domains"]) -> typing.Union[MetaOapg.properties.dns_search_domains, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["udp_port_number"]) -> typing.Union[MetaOapg.properties.udp_port_number, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["dns_enabled"]) -> typing.Union[MetaOapg.properties.dns_enabled, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["keepalive"]) -> typing.Union[MetaOapg.properties.keepalive, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["cidrs"]) -> typing.Union[MetaOapg.properties.cidrs, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["dns_search_domains", "udp_port_number", "dns_enabled", "keepalive", "cidrs", "domains", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    dns_search_domains: typing.Union[MetaOapg.properties.dns_search_domains, str, schemas.Unset] = schemas.unset,
                    udp_port_number: typing.Union[MetaOapg.properties.udp_port_number, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    dns_enabled: typing.Union[MetaOapg.properties.dns_enabled, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    keepalive: typing.Union[MetaOapg.properties.keepalive, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    cidrs: typing.Union[MetaOapg.properties.cidrs, list, tuple, schemas.Unset] = schemas.unset,
                    domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'tunnel_satellite':
                    return super().__new__(
                        cls,
                        *args,
                        dns_search_domains=dns_search_domains,
                        udp_port_number=udp_port_number,
                        dns_enabled=dns_enabled,
                        keepalive=keepalive,
                        cidrs=cidrs,
                        domains=domains,
                        _configuration=_configuration,
                        **kwargs,
                    )
            
            
            class tunnel_enduser(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        dns_search_domains = schemas.StrSchema
                        udp_port_number = schemas.IntSchema
                        dns_enabled = schemas.IntSchema
                        shared_fqdn = schemas.StrSchema
                        keepalive = schemas.IntSchema
                        
                        
                        class cidrs(
                            schemas.ListSchema
                        ):
                        
                        
                            class MetaOapg:
                                items = schemas.StrSchema
                        
                            def __new__(
                                cls,
                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'cidrs':
                                return super().__new__(
                                    cls,
                                    arg,
                                    _configuration=_configuration,
                                )
                        
                            def __getitem__(self, i: int) -> MetaOapg.items:
                                return super().__getitem__(i)
                        
                        
                        class domains(
                            schemas.ListSchema
                        ):
                        
                        
                            class MetaOapg:
                                items = schemas.StrSchema
                        
                            def __new__(
                                cls,
                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'domains':
                                return super().__new__(
                                    cls,
                                    arg,
                                    _configuration=_configuration,
                                )
                        
                            def __getitem__(self, i: int) -> MetaOapg.items:
                                return super().__getitem__(i)
                        __annotations__ = {
                            "dns_search_domains": dns_search_domains,
                            "udp_port_number": udp_port_number,
                            "dns_enabled": dns_enabled,
                            "shared_fqdn": shared_fqdn,
                            "keepalive": keepalive,
                            "cidrs": cidrs,
                            "domains": domains,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["dns_search_domains"]) -> MetaOapg.properties.dns_search_domains: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["udp_port_number"]) -> MetaOapg.properties.udp_port_number: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["dns_enabled"]) -> MetaOapg.properties.dns_enabled: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["shared_fqdn"]) -> MetaOapg.properties.shared_fqdn: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["keepalive"]) -> MetaOapg.properties.keepalive: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["cidrs"]) -> MetaOapg.properties.cidrs: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["dns_search_domains", "udp_port_number", "dns_enabled", "shared_fqdn", "keepalive", "cidrs", "domains", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["dns_search_domains"]) -> typing.Union[MetaOapg.properties.dns_search_domains, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["udp_port_number"]) -> typing.Union[MetaOapg.properties.udp_port_number, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["dns_enabled"]) -> typing.Union[MetaOapg.properties.dns_enabled, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["shared_fqdn"]) -> typing.Union[MetaOapg.properties.shared_fqdn, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["keepalive"]) -> typing.Union[MetaOapg.properties.keepalive, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["cidrs"]) -> typing.Union[MetaOapg.properties.cidrs, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["dns_search_domains", "udp_port_number", "dns_enabled", "shared_fqdn", "keepalive", "cidrs", "domains", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    dns_search_domains: typing.Union[MetaOapg.properties.dns_search_domains, str, schemas.Unset] = schemas.unset,
                    udp_port_number: typing.Union[MetaOapg.properties.udp_port_number, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    dns_enabled: typing.Union[MetaOapg.properties.dns_enabled, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    shared_fqdn: typing.Union[MetaOapg.properties.shared_fqdn, str, schemas.Unset] = schemas.unset,
                    keepalive: typing.Union[MetaOapg.properties.keepalive, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    cidrs: typing.Union[MetaOapg.properties.cidrs, list, tuple, schemas.Unset] = schemas.unset,
                    domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'tunnel_enduser':
                    return super().__new__(
                        cls,
                        *args,
                        dns_search_domains=dns_search_domains,
                        udp_port_number=udp_port_number,
                        dns_enabled=dns_enabled,
                        shared_fqdn=shared_fqdn,
                        keepalive=keepalive,
                        cidrs=cidrs,
                        domains=domains,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "name": name,
                "address": address,
                "domains": domains,
                "cluster_name": cluster_name,
                "disable_snat": disable_snat,
                "src_nat_cidr_range": src_nat_cidr_range,
                "tunnel_satellite": tunnel_satellite,
                "tunnel_enduser": tunnel_enduser,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["cluster_name"]) -> MetaOapg.properties.cluster_name: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["disable_snat"]) -> MetaOapg.properties.disable_snat: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["src_nat_cidr_range"]) -> MetaOapg.properties.src_nat_cidr_range: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tunnel_satellite"]) -> MetaOapg.properties.tunnel_satellite: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["tunnel_enduser"]) -> MetaOapg.properties.tunnel_enduser: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["name", "address", "domains", "cluster_name", "disable_snat", "src_nat_cidr_range", "tunnel_satellite", "tunnel_enduser", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["cluster_name"]) -> typing.Union[MetaOapg.properties.cluster_name, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["disable_snat"]) -> typing.Union[MetaOapg.properties.disable_snat, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["src_nat_cidr_range"]) -> typing.Union[MetaOapg.properties.src_nat_cidr_range, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tunnel_satellite"]) -> typing.Union[MetaOapg.properties.tunnel_satellite, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["tunnel_enduser"]) -> typing.Union[MetaOapg.properties.tunnel_enduser, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["name", "address", "domains", "cluster_name", "disable_snat", "src_nat_cidr_range", "tunnel_satellite", "tunnel_enduser", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
        address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
        domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
        cluster_name: typing.Union[MetaOapg.properties.cluster_name, str, schemas.Unset] = schemas.unset,
        disable_snat: typing.Union[MetaOapg.properties.disable_snat, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        src_nat_cidr_range: typing.Union[MetaOapg.properties.src_nat_cidr_range, str, schemas.Unset] = schemas.unset,
        tunnel_satellite: typing.Union[MetaOapg.properties.tunnel_satellite, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        tunnel_enduser: typing.Union[MetaOapg.properties.tunnel_enduser, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaForRequestBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            name=name,
            address=address,
            domains=domains,
            cluster_name=cluster_name,
            disable_snat=disable_snat,
            src_nat_cidr_range=src_nat_cidr_range,
            tunnel_satellite=tunnel_satellite,
            tunnel_enduser=tunnel_enduser,
            _configuration=_configuration,
            **kwargs,
        )


request_body_any_type = api_client.RequestBody(
    content={
        'application/json': api_client.MediaType(
            schema=SchemaForRequestBodyApplicationJson),
    },
    required=True,
)
_auth = [
    'bearerAuthToken',
]


class SchemaFor200ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            error_code = schemas.IntSchema
            error_description = schemas.StrSchema
            
            
            class data(
                schemas.DictSchema
            ):
            
            
                class MetaOapg:
                    
                    class properties:
                        id = schemas.StrSchema
                        name = schemas.StrSchema
                        address = schemas.StrSchema
                        
                        
                        class domains(
                            schemas.ListSchema
                        ):
                        
                        
                            class MetaOapg:
                                items = schemas.StrSchema
                        
                            def __new__(
                                cls,
                                arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                _configuration: typing.Optional[schemas.Configuration] = None,
                            ) -> 'domains':
                                return super().__new__(
                                    cls,
                                    arg,
                                    _configuration=_configuration,
                                )
                        
                            def __getitem__(self, i: int) -> MetaOapg.items:
                                return super().__getitem__(i)
                        status = schemas.StrSchema
                        netagents = schemas.IntSchema
                        
                        
                        class tunnel_satellite(
                            schemas.DictSchema
                        ):
                        
                        
                            class MetaOapg:
                                
                                class properties:
                                    id = schemas.StrSchema
                                    org_id = schemas.StrSchema
                                    access_tier_id = schemas.StrSchema
                                    tunnel_peer_type = schemas.StrSchema
                                    dns_search_domains = schemas.StrSchema
                                    udp_port_number = schemas.IntSchema
                                    tunnel_ip_address = schemas.StrSchema
                                    wireguard_public_key = schemas.StrSchema
                                    dns_enabled = schemas.IntSchema
                                    keepalive = schemas.IntSchema
                                    created_at = schemas.IntSchema
                                    updated_at = schemas.IntSchema
                                    
                                    
                                    class cidrs(
                                        schemas.ListSchema
                                    ):
                                    
                                    
                                        class MetaOapg:
                                            items = schemas.StrSchema
                                    
                                        def __new__(
                                            cls,
                                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                        ) -> 'cidrs':
                                            return super().__new__(
                                                cls,
                                                arg,
                                                _configuration=_configuration,
                                            )
                                    
                                        def __getitem__(self, i: int) -> MetaOapg.items:
                                            return super().__getitem__(i)
                                    
                                    
                                    class domains(
                                        schemas.ListSchema
                                    ):
                                    
                                    
                                        class MetaOapg:
                                            items = schemas.StrSchema
                                    
                                        def __new__(
                                            cls,
                                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                        ) -> 'domains':
                                            return super().__new__(
                                                cls,
                                                arg,
                                                _configuration=_configuration,
                                            )
                                    
                                        def __getitem__(self, i: int) -> MetaOapg.items:
                                            return super().__getitem__(i)
                                    client_cidr_range = schemas.StrSchema
                                    __annotations__ = {
                                        "id": id,
                                        "org_id": org_id,
                                        "access_tier_id": access_tier_id,
                                        "tunnel_peer_type": tunnel_peer_type,
                                        "dns_search_domains": dns_search_domains,
                                        "udp_port_number": udp_port_number,
                                        "tunnel_ip_address": tunnel_ip_address,
                                        "wireguard_public_key": wireguard_public_key,
                                        "dns_enabled": dns_enabled,
                                        "keepalive": keepalive,
                                        "created_at": created_at,
                                        "updated_at": updated_at,
                                        "cidrs": cidrs,
                                        "domains": domains,
                                        "client_cidr_range": client_cidr_range,
                                    }
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["org_id"]) -> MetaOapg.properties.org_id: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["access_tier_id"]) -> MetaOapg.properties.access_tier_id: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> MetaOapg.properties.tunnel_peer_type: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["dns_search_domains"]) -> MetaOapg.properties.dns_search_domains: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["udp_port_number"]) -> MetaOapg.properties.udp_port_number: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> MetaOapg.properties.tunnel_ip_address: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["wireguard_public_key"]) -> MetaOapg.properties.wireguard_public_key: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["dns_enabled"]) -> MetaOapg.properties.dns_enabled: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["keepalive"]) -> MetaOapg.properties.keepalive: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["cidrs"]) -> MetaOapg.properties.cidrs: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["client_cidr_range"]) -> MetaOapg.properties.client_cidr_range: ...
                            
                            @typing.overload
                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                            
                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                # dict_instance[name] accessor
                                return super().__getitem__(name)
                            
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["org_id"]) -> typing.Union[MetaOapg.properties.org_id, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["access_tier_id"]) -> typing.Union[MetaOapg.properties.access_tier_id, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> typing.Union[MetaOapg.properties.tunnel_peer_type, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["dns_search_domains"]) -> typing.Union[MetaOapg.properties.dns_search_domains, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["udp_port_number"]) -> typing.Union[MetaOapg.properties.udp_port_number, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> typing.Union[MetaOapg.properties.tunnel_ip_address, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["wireguard_public_key"]) -> typing.Union[MetaOapg.properties.wireguard_public_key, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["dns_enabled"]) -> typing.Union[MetaOapg.properties.dns_enabled, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["keepalive"]) -> typing.Union[MetaOapg.properties.keepalive, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["cidrs"]) -> typing.Union[MetaOapg.properties.cidrs, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["client_cidr_range"]) -> typing.Union[MetaOapg.properties.client_cidr_range, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                            
                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                return super().get_item_oapg(name)
                            
                        
                            def __new__(
                                cls,
                                *args: typing.Union[dict, frozendict.frozendict, ],
                                id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                                org_id: typing.Union[MetaOapg.properties.org_id, str, schemas.Unset] = schemas.unset,
                                access_tier_id: typing.Union[MetaOapg.properties.access_tier_id, str, schemas.Unset] = schemas.unset,
                                tunnel_peer_type: typing.Union[MetaOapg.properties.tunnel_peer_type, str, schemas.Unset] = schemas.unset,
                                dns_search_domains: typing.Union[MetaOapg.properties.dns_search_domains, str, schemas.Unset] = schemas.unset,
                                udp_port_number: typing.Union[MetaOapg.properties.udp_port_number, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                tunnel_ip_address: typing.Union[MetaOapg.properties.tunnel_ip_address, str, schemas.Unset] = schemas.unset,
                                wireguard_public_key: typing.Union[MetaOapg.properties.wireguard_public_key, str, schemas.Unset] = schemas.unset,
                                dns_enabled: typing.Union[MetaOapg.properties.dns_enabled, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                keepalive: typing.Union[MetaOapg.properties.keepalive, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                created_at: typing.Union[MetaOapg.properties.created_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                updated_at: typing.Union[MetaOapg.properties.updated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                cidrs: typing.Union[MetaOapg.properties.cidrs, list, tuple, schemas.Unset] = schemas.unset,
                                domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                                client_cidr_range: typing.Union[MetaOapg.properties.client_cidr_range, str, schemas.Unset] = schemas.unset,
                                _configuration: typing.Optional[schemas.Configuration] = None,
                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                            ) -> 'tunnel_satellite':
                                return super().__new__(
                                    cls,
                                    *args,
                                    id=id,
                                    org_id=org_id,
                                    access_tier_id=access_tier_id,
                                    tunnel_peer_type=tunnel_peer_type,
                                    dns_search_domains=dns_search_domains,
                                    udp_port_number=udp_port_number,
                                    tunnel_ip_address=tunnel_ip_address,
                                    wireguard_public_key=wireguard_public_key,
                                    dns_enabled=dns_enabled,
                                    keepalive=keepalive,
                                    created_at=created_at,
                                    updated_at=updated_at,
                                    cidrs=cidrs,
                                    domains=domains,
                                    client_cidr_range=client_cidr_range,
                                    _configuration=_configuration,
                                    **kwargs,
                                )
                        
                        
                        class tunnel_enduser(
                            schemas.DictSchema
                        ):
                        
                        
                            class MetaOapg:
                                
                                class properties:
                                    id = schemas.StrSchema
                                    org_id = schemas.StrSchema
                                    access_tier_id = schemas.StrSchema
                                    tunnel_peer_type = schemas.StrSchema
                                    dns_search_domains = schemas.StrSchema
                                    udp_port_number = schemas.IntSchema
                                    tunnel_ip_address = schemas.StrSchema
                                    wireguard_public_key = schemas.StrSchema
                                    dns_enabled = schemas.IntSchema
                                    keepalive = schemas.IntSchema
                                    created_at = schemas.IntSchema
                                    updated_at = schemas.IntSchema
                                    
                                    
                                    class cidrs(
                                        schemas.ListSchema
                                    ):
                                    
                                    
                                        class MetaOapg:
                                            items = schemas.StrSchema
                                    
                                        def __new__(
                                            cls,
                                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                        ) -> 'cidrs':
                                            return super().__new__(
                                                cls,
                                                arg,
                                                _configuration=_configuration,
                                            )
                                    
                                        def __getitem__(self, i: int) -> MetaOapg.items:
                                            return super().__getitem__(i)
                                    
                                    
                                    class domains(
                                        schemas.ListSchema
                                    ):
                                    
                                    
                                        class MetaOapg:
                                            items = schemas.StrSchema
                                    
                                        def __new__(
                                            cls,
                                            arg: typing.Union[typing.Tuple[typing.Union[MetaOapg.items, str, ]], typing.List[typing.Union[MetaOapg.items, str, ]]],
                                            _configuration: typing.Optional[schemas.Configuration] = None,
                                        ) -> 'domains':
                                            return super().__new__(
                                                cls,
                                                arg,
                                                _configuration=_configuration,
                                            )
                                    
                                        def __getitem__(self, i: int) -> MetaOapg.items:
                                            return super().__getitem__(i)
                                    client_cidr_range = schemas.StrSchema
                                    __annotations__ = {
                                        "id": id,
                                        "org_id": org_id,
                                        "access_tier_id": access_tier_id,
                                        "tunnel_peer_type": tunnel_peer_type,
                                        "dns_search_domains": dns_search_domains,
                                        "udp_port_number": udp_port_number,
                                        "tunnel_ip_address": tunnel_ip_address,
                                        "wireguard_public_key": wireguard_public_key,
                                        "dns_enabled": dns_enabled,
                                        "keepalive": keepalive,
                                        "created_at": created_at,
                                        "updated_at": updated_at,
                                        "cidrs": cidrs,
                                        "domains": domains,
                                        "client_cidr_range": client_cidr_range,
                                    }
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["org_id"]) -> MetaOapg.properties.org_id: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["access_tier_id"]) -> MetaOapg.properties.access_tier_id: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> MetaOapg.properties.tunnel_peer_type: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["dns_search_domains"]) -> MetaOapg.properties.dns_search_domains: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["udp_port_number"]) -> MetaOapg.properties.udp_port_number: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> MetaOapg.properties.tunnel_ip_address: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["wireguard_public_key"]) -> MetaOapg.properties.wireguard_public_key: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["dns_enabled"]) -> MetaOapg.properties.dns_enabled: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["keepalive"]) -> MetaOapg.properties.keepalive: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["cidrs"]) -> MetaOapg.properties.cidrs: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                            
                            @typing.overload
                            def __getitem__(self, name: typing_extensions.Literal["client_cidr_range"]) -> MetaOapg.properties.client_cidr_range: ...
                            
                            @typing.overload
                            def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                            
                            def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                # dict_instance[name] accessor
                                return super().__getitem__(name)
                            
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["org_id"]) -> typing.Union[MetaOapg.properties.org_id, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["access_tier_id"]) -> typing.Union[MetaOapg.properties.access_tier_id, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["tunnel_peer_type"]) -> typing.Union[MetaOapg.properties.tunnel_peer_type, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["dns_search_domains"]) -> typing.Union[MetaOapg.properties.dns_search_domains, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["udp_port_number"]) -> typing.Union[MetaOapg.properties.udp_port_number, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["tunnel_ip_address"]) -> typing.Union[MetaOapg.properties.tunnel_ip_address, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["wireguard_public_key"]) -> typing.Union[MetaOapg.properties.wireguard_public_key, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["dns_enabled"]) -> typing.Union[MetaOapg.properties.dns_enabled, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["keepalive"]) -> typing.Union[MetaOapg.properties.keepalive, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["cidrs"]) -> typing.Union[MetaOapg.properties.cidrs, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: typing_extensions.Literal["client_cidr_range"]) -> typing.Union[MetaOapg.properties.client_cidr_range, schemas.Unset]: ...
                            
                            @typing.overload
                            def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                            
                            def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "org_id", "access_tier_id", "tunnel_peer_type", "dns_search_domains", "udp_port_number", "tunnel_ip_address", "wireguard_public_key", "dns_enabled", "keepalive", "created_at", "updated_at", "cidrs", "domains", "client_cidr_range", ], str]):
                                return super().get_item_oapg(name)
                            
                        
                            def __new__(
                                cls,
                                *args: typing.Union[dict, frozendict.frozendict, ],
                                id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                                org_id: typing.Union[MetaOapg.properties.org_id, str, schemas.Unset] = schemas.unset,
                                access_tier_id: typing.Union[MetaOapg.properties.access_tier_id, str, schemas.Unset] = schemas.unset,
                                tunnel_peer_type: typing.Union[MetaOapg.properties.tunnel_peer_type, str, schemas.Unset] = schemas.unset,
                                dns_search_domains: typing.Union[MetaOapg.properties.dns_search_domains, str, schemas.Unset] = schemas.unset,
                                udp_port_number: typing.Union[MetaOapg.properties.udp_port_number, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                tunnel_ip_address: typing.Union[MetaOapg.properties.tunnel_ip_address, str, schemas.Unset] = schemas.unset,
                                wireguard_public_key: typing.Union[MetaOapg.properties.wireguard_public_key, str, schemas.Unset] = schemas.unset,
                                dns_enabled: typing.Union[MetaOapg.properties.dns_enabled, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                keepalive: typing.Union[MetaOapg.properties.keepalive, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                created_at: typing.Union[MetaOapg.properties.created_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                updated_at: typing.Union[MetaOapg.properties.updated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                                cidrs: typing.Union[MetaOapg.properties.cidrs, list, tuple, schemas.Unset] = schemas.unset,
                                domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                                client_cidr_range: typing.Union[MetaOapg.properties.client_cidr_range, str, schemas.Unset] = schemas.unset,
                                _configuration: typing.Optional[schemas.Configuration] = None,
                                **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                            ) -> 'tunnel_enduser':
                                return super().__new__(
                                    cls,
                                    *args,
                                    id=id,
                                    org_id=org_id,
                                    access_tier_id=access_tier_id,
                                    tunnel_peer_type=tunnel_peer_type,
                                    dns_search_domains=dns_search_domains,
                                    udp_port_number=udp_port_number,
                                    tunnel_ip_address=tunnel_ip_address,
                                    wireguard_public_key=wireguard_public_key,
                                    dns_enabled=dns_enabled,
                                    keepalive=keepalive,
                                    created_at=created_at,
                                    updated_at=updated_at,
                                    cidrs=cidrs,
                                    domains=domains,
                                    client_cidr_range=client_cidr_range,
                                    _configuration=_configuration,
                                    **kwargs,
                                )
                        created_at = schemas.IntSchema
                        created_by = schemas.StrSchema
                        updated_at = schemas.IntSchema
                        updated_by = schemas.StrSchema
                        cluster_name = schemas.StrSchema
                        __annotations__ = {
                            "id": id,
                            "name": name,
                            "address": address,
                            "domains": domains,
                            "status": status,
                            "netagents": netagents,
                            "tunnel_satellite": tunnel_satellite,
                            "tunnel_enduser": tunnel_enduser,
                            "created_at": created_at,
                            "created_by": created_by,
                            "updated_at": updated_at,
                            "updated_by": updated_by,
                            "cluster_name": cluster_name,
                        }
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["id"]) -> MetaOapg.properties.id: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["name"]) -> MetaOapg.properties.name: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["address"]) -> MetaOapg.properties.address: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["domains"]) -> MetaOapg.properties.domains: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["status"]) -> MetaOapg.properties.status: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["netagents"]) -> MetaOapg.properties.netagents: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["tunnel_satellite"]) -> MetaOapg.properties.tunnel_satellite: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["tunnel_enduser"]) -> MetaOapg.properties.tunnel_enduser: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["created_at"]) -> MetaOapg.properties.created_at: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["created_by"]) -> MetaOapg.properties.created_by: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["updated_at"]) -> MetaOapg.properties.updated_at: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["updated_by"]) -> MetaOapg.properties.updated_by: ...
                
                @typing.overload
                def __getitem__(self, name: typing_extensions.Literal["cluster_name"]) -> MetaOapg.properties.cluster_name: ...
                
                @typing.overload
                def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
                
                def __getitem__(self, name: typing.Union[typing_extensions.Literal["id", "name", "address", "domains", "status", "netagents", "tunnel_satellite", "tunnel_enduser", "created_at", "created_by", "updated_at", "updated_by", "cluster_name", ], str]):
                    # dict_instance[name] accessor
                    return super().__getitem__(name)
                
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["id"]) -> typing.Union[MetaOapg.properties.id, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["name"]) -> typing.Union[MetaOapg.properties.name, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["address"]) -> typing.Union[MetaOapg.properties.address, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["domains"]) -> typing.Union[MetaOapg.properties.domains, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["status"]) -> typing.Union[MetaOapg.properties.status, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["netagents"]) -> typing.Union[MetaOapg.properties.netagents, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["tunnel_satellite"]) -> typing.Union[MetaOapg.properties.tunnel_satellite, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["tunnel_enduser"]) -> typing.Union[MetaOapg.properties.tunnel_enduser, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["created_at"]) -> typing.Union[MetaOapg.properties.created_at, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["created_by"]) -> typing.Union[MetaOapg.properties.created_by, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["updated_at"]) -> typing.Union[MetaOapg.properties.updated_at, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["updated_by"]) -> typing.Union[MetaOapg.properties.updated_by, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: typing_extensions.Literal["cluster_name"]) -> typing.Union[MetaOapg.properties.cluster_name, schemas.Unset]: ...
                
                @typing.overload
                def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
                
                def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["id", "name", "address", "domains", "status", "netagents", "tunnel_satellite", "tunnel_enduser", "created_at", "created_by", "updated_at", "updated_by", "cluster_name", ], str]):
                    return super().get_item_oapg(name)
                
            
                def __new__(
                    cls,
                    *args: typing.Union[dict, frozendict.frozendict, ],
                    id: typing.Union[MetaOapg.properties.id, str, schemas.Unset] = schemas.unset,
                    name: typing.Union[MetaOapg.properties.name, str, schemas.Unset] = schemas.unset,
                    address: typing.Union[MetaOapg.properties.address, str, schemas.Unset] = schemas.unset,
                    domains: typing.Union[MetaOapg.properties.domains, list, tuple, schemas.Unset] = schemas.unset,
                    status: typing.Union[MetaOapg.properties.status, str, schemas.Unset] = schemas.unset,
                    netagents: typing.Union[MetaOapg.properties.netagents, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    tunnel_satellite: typing.Union[MetaOapg.properties.tunnel_satellite, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                    tunnel_enduser: typing.Union[MetaOapg.properties.tunnel_enduser, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
                    created_at: typing.Union[MetaOapg.properties.created_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    created_by: typing.Union[MetaOapg.properties.created_by, str, schemas.Unset] = schemas.unset,
                    updated_at: typing.Union[MetaOapg.properties.updated_at, decimal.Decimal, int, schemas.Unset] = schemas.unset,
                    updated_by: typing.Union[MetaOapg.properties.updated_by, str, schemas.Unset] = schemas.unset,
                    cluster_name: typing.Union[MetaOapg.properties.cluster_name, str, schemas.Unset] = schemas.unset,
                    _configuration: typing.Optional[schemas.Configuration] = None,
                    **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
                ) -> 'data':
                    return super().__new__(
                        cls,
                        *args,
                        id=id,
                        name=name,
                        address=address,
                        domains=domains,
                        status=status,
                        netagents=netagents,
                        tunnel_satellite=tunnel_satellite,
                        tunnel_enduser=tunnel_enduser,
                        created_at=created_at,
                        created_by=created_by,
                        updated_at=updated_at,
                        updated_by=updated_by,
                        cluster_name=cluster_name,
                        _configuration=_configuration,
                        **kwargs,
                    )
            __annotations__ = {
                "request_id": request_id,
                "error_code": error_code,
                "error_description": error_description,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_code"]) -> MetaOapg.properties.error_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_code"]) -> typing.Union[MetaOapg.properties.error_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        error_code: typing.Union[MetaOapg.properties.error_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, dict, frozendict.frozendict, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor200ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            request_id=request_id,
            error_code=error_code,
            error_description=error_description,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor200(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor200ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_200 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor200,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor200ResponseBodyApplicationJson),
    },
)


class SchemaFor400ResponseBodyApplicationJson(
    schemas.DictSchema
):


    class MetaOapg:
        
        class properties:
            request_id = schemas.StrSchema
            error_code = schemas.IntSchema
            error_description = schemas.StrSchema
            data = schemas.IntSchema
            __annotations__ = {
                "request_id": request_id,
                "error_code": error_code,
                "error_description": error_description,
                "data": data,
            }
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["request_id"]) -> MetaOapg.properties.request_id: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_code"]) -> MetaOapg.properties.error_code: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["error_description"]) -> MetaOapg.properties.error_description: ...
    
    @typing.overload
    def __getitem__(self, name: typing_extensions.Literal["data"]) -> MetaOapg.properties.data: ...
    
    @typing.overload
    def __getitem__(self, name: str) -> schemas.UnsetAnyTypeSchema: ...
    
    def __getitem__(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        # dict_instance[name] accessor
        return super().__getitem__(name)
    
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["request_id"]) -> typing.Union[MetaOapg.properties.request_id, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_code"]) -> typing.Union[MetaOapg.properties.error_code, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["error_description"]) -> typing.Union[MetaOapg.properties.error_description, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: typing_extensions.Literal["data"]) -> typing.Union[MetaOapg.properties.data, schemas.Unset]: ...
    
    @typing.overload
    def get_item_oapg(self, name: str) -> typing.Union[schemas.UnsetAnyTypeSchema, schemas.Unset]: ...
    
    def get_item_oapg(self, name: typing.Union[typing_extensions.Literal["request_id", "error_code", "error_description", "data", ], str]):
        return super().get_item_oapg(name)
    

    def __new__(
        cls,
        *args: typing.Union[dict, frozendict.frozendict, ],
        request_id: typing.Union[MetaOapg.properties.request_id, str, schemas.Unset] = schemas.unset,
        error_code: typing.Union[MetaOapg.properties.error_code, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        error_description: typing.Union[MetaOapg.properties.error_description, str, schemas.Unset] = schemas.unset,
        data: typing.Union[MetaOapg.properties.data, decimal.Decimal, int, schemas.Unset] = schemas.unset,
        _configuration: typing.Optional[schemas.Configuration] = None,
        **kwargs: typing.Union[schemas.AnyTypeSchema, dict, frozendict.frozendict, str, date, datetime, uuid.UUID, int, float, decimal.Decimal, None, list, tuple, bytes],
    ) -> 'SchemaFor400ResponseBodyApplicationJson':
        return super().__new__(
            cls,
            *args,
            request_id=request_id,
            error_code=error_code,
            error_description=error_description,
            data=data,
            _configuration=_configuration,
            **kwargs,
        )


@dataclass
class ApiResponseFor400(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: typing.Union[
        SchemaFor400ResponseBodyApplicationJson,
    ]
    headers: schemas.Unset = schemas.unset


_response_for_400 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor400,
    content={
        'application/json': api_client.MediaType(
            schema=SchemaFor400ResponseBodyApplicationJson),
    },
)


@dataclass
class ApiResponseFor401(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_401 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor401,
)


@dataclass
class ApiResponseFor500(api_client.ApiResponse):
    response: urllib3.HTTPResponse
    body: schemas.Unset = schemas.unset
    headers: schemas.Unset = schemas.unset


_response_for_500 = api_client.OpenApiResponse(
    response_cls=ApiResponseFor500,
)
_status_code_to_response = {
    '200': _response_for_200,
    '400': _response_for_400,
    '401': _response_for_401,
    '500': _response_for_500,
}
_all_accept_content_types = (
    'application/json',
)


class BaseApi(api_client.Api):

    def _v2_access_tier_post_oapg(
        self: api_client.Api,
        body: typing.Union[SchemaForRequestBodyApplicationJson, dict, frozendict.frozendict, ],
        query_params: RequestQueryParams = frozendict.frozendict(),
        content_type: str = 'application/json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        """
         Create Access Tier for an organization
        :param skip_deserialization: If true then api_response.response will be set but
            api_response.body and api_response.headers will not be deserialized into schema
            class instances
        """
        self._verify_typed_dict_inputs_oapg(RequestQueryParams, query_params)
        used_path = path.value

        prefix_separator_iterator = None
        for parameter in (
            request_query_name,
            request_query_address,
            request_query_domains,
            request_query_tunnel_satellite,
            request_query_tunnel_enduser,
            request_query_cluster_name,
        ):
            parameter_data = query_params.get(parameter.name, schemas.unset)
            if parameter_data is schemas.unset:
                continue
            if prefix_separator_iterator is None:
                prefix_separator_iterator = parameter.get_prefix_separator_iterator()
            serialized_data = parameter.serialize(parameter_data, prefix_separator_iterator)
            for serialized_value in serialized_data.values():
                used_path += serialized_value

        _headers = HTTPHeaderDict()
        # TODO add cookie handling
        if accept_content_types:
            for accept_content_type in accept_content_types:
                _headers.add('Accept', accept_content_type)

        if body is schemas.unset:
            raise exceptions.ApiValueError(
                'The required body parameter has an invalid value of: unset. Set a valid value instead')
        _fields = None
        _body = None
        serialized_data = request_body_any_type.serialize(body, content_type)
        _headers.add('Content-Type', content_type)
        if 'fields' in serialized_data:
            _fields = serialized_data['fields']
        elif 'body' in serialized_data:
            _body = serialized_data['body']
        response = self.api_client.call_api(
            resource_path=used_path,
            method='post'.upper(),
            headers=_headers,
            fields=_fields,
            body=_body,
            auth_settings=_auth,
            stream=stream,
            timeout=timeout,
        )

        if skip_deserialization:
            api_response = api_client.ApiResponseWithoutDeserialization(response=response)
        else:
            response_for_status = _status_code_to_response.get(str(response.status))
            if response_for_status:
                api_response = response_for_status.deserialize(response, self.api_client.configuration)
            else:
                api_response = api_client.ApiResponseWithoutDeserialization(response=response)

        if not 200 <= response.status <= 299:
            raise exceptions.ApiException(api_response=api_response)

        return api_response


class V2AccessTierPost(BaseApi):
    # this class is used by api classes that refer to endpoints with operationId fn names

    def v2_access_tier_post(
        self: BaseApi,
        body: typing.Union[SchemaForRequestBodyApplicationJson, dict, frozendict.frozendict, ],
        query_params: RequestQueryParams = frozendict.frozendict(),
        content_type: str = 'application/json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_access_tier_post_oapg(
            body=body,
            query_params=query_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )


class ApiForpost(BaseApi):
    # this class is used by api classes that refer to endpoints by path and http method names

    def post(
        self: BaseApi,
        body: typing.Union[SchemaForRequestBodyApplicationJson, dict, frozendict.frozendict, ],
        query_params: RequestQueryParams = frozendict.frozendict(),
        content_type: str = 'application/json',
        accept_content_types: typing.Tuple[str] = _all_accept_content_types,
        stream: bool = False,
        timeout: typing.Optional[typing.Union[int, typing.Tuple]] = None,
        skip_deserialization: bool = False,
    ) -> typing.Union[
        ApiResponseFor200,
        api_client.ApiResponseWithoutDeserialization
    ]:
        return self._v2_access_tier_post_oapg(
            body=body,
            query_params=query_params,
            content_type=content_type,
            accept_content_types=accept_content_types,
            stream=stream,
            timeout=timeout,
            skip_deserialization=skip_deserialization
        )





# coding: utf-8

"""
    Banyan Rest APIs

    This swagger spec contains list of all Banyan APIs.  # noqa: E501

    The version of the OpenAPI document: 1.0
    Generated by: https://openapi-generator.tech
"""

from banyanclient.paths.service_tunnel_id_security_policy.get import ServiceTunnelIdSecurityPolicyGet
from banyanclient.paths.service_tunnel_id_security_policy_policy_id.delete import ServiceTunnelIdSecurityPolicyPolicyIdDelete
from banyanclient.paths.service_tunnel_id_security_policy.post import ServiceTunnelIdSecurityPolicyPost
from banyanclient.paths.v2_service_tunnel.get import V2ServiceTunnelGet
from banyanclient.paths.v2_service_tunnel_id.delete import V2ServiceTunnelIdDelete
from banyanclient.paths.v2_service_tunnel_id.get import V2ServiceTunnelIdGet
from banyanclient.paths.v2_service_tunnel_id.put import V2ServiceTunnelIdPut
from banyanclient.paths.v2_service_tunnel.post import V2ServiceTunnelPost


class ServiceTunnelApi(
    ServiceTunnelIdSecurityPolicyGet,
    ServiceTunnelIdSecurityPolicyPolicyIdDelete,
    ServiceTunnelIdSecurityPolicyPost,
    V2ServiceTunnelGet,
    V2ServiceTunnelIdDelete,
    V2ServiceTunnelIdGet,
    V2ServiceTunnelIdPut,
    V2ServiceTunnelPost,
):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """
    pass
